@@ -17,20 +17,22 @@ class ProcessListTab(QTabWidget, Ui_ProcessListWidget):
         cur = self.connection.cursor()
         cur.execute("SHOW TABLES IN information_schema LIKE 'PROCESSLIST'")
         self.processListInInfoSchema = cur.rowcount
-        self.processListColumns = []
-        cur.execute("SHOW COLUMNS IN information_schema.PROCESSLIST")
-        for column in cur.fetchall():
-            self.processListColumns.append(column[0])
-        try:
-            self.processListColumns.remove("HOST")
-        except ValueError:
-            pass
-        try:
-            self.processListColumns.remove("TIME_MS")
-            idx_time = self.processListColumns.index("TIME")
-            self.processListColumns[idx_time] = "TIME + TIME_MS/1000 AS TIME"
-        except ValueError:
-            pass
+
+        if self.processListInInfoSchema:
+            self.processListColumns = []
+            cur.execute("SHOW COLUMNS IN information_schema.PROCESSLIST")
+            for column in cur.fetchall():
+                self.processListColumns.append(column[0])
+
+            try:
+                self.processListColumns.remove("TIME_MS")
+                idx_time = self.processListColumns.index("TIME")
+                self.processListColumns[idx_time] = "TIME + TIME_MS/1000 AS TIME"
+            except ValueError:
+                pass
+
+        else:
+            self.chkShowIdle.hide()
 
         self.refresh()
 
@@ -59,7 +61,8 @@ class ProcessListTab(QTabWidget, Ui_ProcessListWidget):
     def refresh(self):
         queryModel = QPySelectModel(self, self.connection)
         if self.processListInInfoSchema:
-            queryModel.setSelect( "SELECT %s FROM information_schema.PROCESSLIST ORDER BY TIME DESC" % ",".join(self.processListColumns) )
+            where = "" if self.chkShowIdle.isChecked() else "WHERE STATE != ''"
+            queryModel.setSelect( "SELECT %s FROM information_schema.PROCESSLIST %s ORDER BY TIME DESC" % (",".join(self.processListColumns), where) )
         else:
             queryModel.setSelect( "SHOW FULL PROCESSLIST" )
         queryModel.select()
